==> igniteui-react-core-18.0.0.tgz: package/esm5/lib/ToolActionSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionSeparatorDescription } from "./ToolActionSeparatorDescription";
/**
 * @hidden
 */
var ToolActionSeparatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionSeparatorDescriptionMetadata, _super);
    function ToolActionSeparatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionSeparatorDescriptionMetadata.b = function (a) {
        if (ToolActionSeparatorDescriptionMetadata.a == null) {
            ToolActionSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionSeparatorDescriptionMetadata.c(ToolActionSeparatorDescriptionMetadata.a);
        }
        if (a.g(ToolActionSeparatorDescriptionMetadata.a)) {
            return;
        }
        a.s(ToolActionSeparatorDescriptionMetadata.a);
    };
    ToolActionSeparatorDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
    };
    ToolActionSeparatorDescriptionMetadata.d = function (a) {
        ToolActionSeparatorDescriptionMetadata.b(a);
        a.u("ToolActionSeparator", function () { return new ToolActionSeparatorDescription(); });
        a.t("ToolActionSeparator", ToolActionSeparatorDescriptionMetadata.a);
    };
    ToolActionSeparatorDescriptionMetadata.$t = markType(ToolActionSeparatorDescriptionMetadata, 'ToolActionSeparatorDescriptionMetadata');
    ToolActionSeparatorDescriptionMetadata.a = null;
    return ToolActionSeparatorDescriptionMetadata;
}(Base));
export { ToolActionSeparatorDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ToolActionSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionSeparatorDescription } from "./ToolActionSeparatorDescription";
/**
 * @hidden
 */
var ToolActionSeparatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionSeparatorDescriptionMetadata, _super);
    function ToolActionSeparatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionSeparatorDescriptionMetadata.b = function (a) {
        if (ToolActionSeparatorDescriptionMetadata.a == null) {
            ToolActionSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionSeparatorDescriptionMetadata.c(ToolActionSeparatorDescriptionMetadata.a);
        }
        if (a.j(ToolActionSeparatorDescriptionMetadata.a)) {
            return;
        }
        a.y(ToolActionSeparatorDescriptionMetadata.a);
    };
    ToolActionSeparatorDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
    };
    ToolActionSeparatorDescriptionMetadata.d = function (a) {
        ToolActionSeparatorDescriptionMetadata.b(a);
        a.aa("ToolActionSeparator", function () { return new ToolActionSeparatorDescription(); });
        a.z("ToolActionSeparator", ToolActionSeparatorDescriptionMetadata.a);
    };
    ToolActionSeparatorDescriptionMetadata.$t = markType(ToolActionSeparatorDescriptionMetadata, 'ToolActionSeparatorDescriptionMetadata');
    ToolActionSeparatorDescriptionMetadata.a = null;
    return ToolActionSeparatorDescriptionMetadata;
}(Base));
export { ToolActionSeparatorDescriptionMetadata };
